import { NgForm } from '@angular/forms';
/**
 * Builder responsible for validate and update form
 */
export declare class FormValidatorBuilder<T> {
    /**
     * Custom validator to be executed
     */
    private _custom;
    /**
     * Form instance
     */
    private readonly form;
    /**
     * Function executed when form is invalid
     */
    private _invalid;
    /**
     * Function executed when form is valid
     */
    private _valid;
    /**
     * Used to create a new instance of the builder
     * Receive a BasePage instance and a form instance
     * @constructor
     * @param form: any
     */
    constructor(form: NgForm);
    /**
     * Add valid callback to form
     * @param callback: function
     */
    valid(callback: () => any): FormValidatorBuilder<T>;
    /**
     * Add invalid callback to form
     * @param callback: function
     */
    invalid(callback: () => any): FormValidatorBuilder<T>;
    /**
     * Add custom validators to form
     * @param callback: function
     */
    validator(callback: () => boolean): this;
    /**
     * Execute validator and return if has errors
     */
    private isValidatorsInvalid;
    /**
     * Validate the form
     */
    validate(): void;
}
