import { Observable } from 'rxjs';
/**
 * Class responsible to create a builder to execute endpoint request
 * It already trigger loading
 *
 * @example
 *
 * new RequestBuilder<U>(page, obs)
 * .success(() => {})
 * .error(() => {})
 * .do();
 */
export declare class RequestBuilder<S = any, E = any> {
    /**
     * Observable to be executed (request)
     */
    private obs;
    /**
     * Base class to start loading
     */
    private base;
    /**
     * Used to not present loader
     */
    private _loader;
    /**
     * Used to not dismmiss loader
     */
    private _dismiss;
    /**
     * Function executed before make the request
     */
    private _prepare;
    /**
     * Function executed on success
     */
    private _success;
    /**
     * Function executed on error
     */
    private _error;
    /**
     * Function executed every time, on error or on success
     */
    private _finally;
    /**
     * Used to create a new instance of the builder
     * Must receive a BasePage and a Observable
     * @constructor
     * @param obs: Observable<any>
     * @param base: aby
     */
    constructor(obs: Observable<any>, base: any);
    /**
     * Add if should not present loader (default: true)
     * @param value: boolean
     */
    loader(value?: boolean): RequestBuilder<S, E>;
    /**
     * Add if should not dismiss loader (default: true)
     * @param value: boolean
     */
    dismiss(value?: boolean): RequestBuilder<S, E>;
    /**
     * Add a prepare function to be executed before execute request
     * @param callback: function(any)
     */
    prepare(callback: (resp: any) => any): RequestBuilder<S, E>;
    /**
     * Add success function to builder
     * @param callback: function(any)
     */
    success(callback: (resp: S) => any): this;
    /**
     * Add a error function to builder
     * @param callback: function(ErrorResponse)
     */
    error(callback: (err: E) => any): RequestBuilder<S, E>;
    /**
     * Add a finally function to builder
     * @param callback: function()
     */
    finally(callback: () => any): RequestBuilder<S, E>;
    /**
     * Execute the request
     */
    do(): void;
    /**
     * Dismiss base class loader
     * @private
     */
    private _dismissBaseLoader;
}
