import { NgForm } from '@angular/forms';
import { Injector } from '@angular/core';
import { Observable } from 'rxjs';
import { FormValidatorBuilder, RequestBuilder } from '../builders';
import { RhzCommon } from './common.class';
export declare class RhzBase extends RhzCommon {
    /**
     * Controls loader visibility
     */
    private loading;
    /**
     * Controls initializing visibility
     */
    private initializing;
    /**
     * Define if platform is browser or server
     */
    private readonly isBrowser;
    /**
     * Inject dependencies
     * @param injector: Injector
     */
    constructor(injector: Injector);
    /**
     * show loader
     */
    showLoader(): void;
    /**
     * Hide loader
     */
    dismissLoader(): void;
    /**
     * Return if is loading
     */
    isLoading(): boolean;
    /**
     * Set initializing attribute
     */
    setInitializing(value: boolean): void;
    /**
     * Return if is filtering
     */
    isInitializing(): boolean;
    /**
     * Should execute before start a request
     */
    onRequestStart(): void;
    /**
     * Execute on request error
     * @param message: string
     */
    onError(message?: string): void;
    /**
     * Used to make a request
     * @param obs: Observable<any>
     * @type <S, E>: S = success type - E = error type
     */
    doRequest<S = any, E = any>(obs: Observable<any>): RequestBuilder<S, E>;
    /**
     * Verify if form is valid and apply validation
     * @param form: NgForm
     */
    isFormValid(form: NgForm): FormValidatorBuilder<RhzBase>;
    /**
     * Show error alert
     * @param title: string
     * @param message: string
     */
    onErrorAlert(title: string, message: string): void;
    /**
     * Show warning alert
     * @param title: string
     * @param message: string
     */
    onWarningAlert(title: string, message: string): void;
    /**
     * Show confirmation alert
     * @param title: string
     * @param message: string
     * @param confirmCallback: function
     * @param cancelCallback: function
     */
    onConfirmationAlert(title: string, message?: string, confirmCallback?: () => any, cancelCallback?: () => any): void;
    /**
     * Execute when request success
     * @param message: string
     */
    onSuccess(message: string): void;
}
