import { OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { MatFormFieldControl } from '@angular/material/form-field';
import { Subject } from 'rxjs';
import { QuillEditorComponent } from 'ngx-quill';
import { RhzEditorConfig } from './interfaces/config.interface';
export declare class RhzEditorComponent implements OnInit, OnDestroy, ControlValueAccessor, MatFormFieldControl<any> {
    /**
     * View child
     */
    quillEditor: QuillEditorComponent;
    /**
     * Properties
     */
    /**
     * Format text boxes 'bold' | 'italic' | 'underline | 'strike'
     *
     */
    private _textFormat;
    /**
     * Blockquote and block code 'blockquote' | 'code-block'
     */
    private _blockQuotes;
    /**
     * Format text headers
     */
    private _headers;
    /**
     * Ordering list format 'ordered' | 'bullet'
     */
    private _list;
    /**
     * Identation box
     */
    private _ident;
    /**
     * Direction box
     */
    private _direction;
    /**
     * Default sizes 'small' | 'large' | 'huge'
     */
    private _sizes;
    /**
     * Colors and background
     */
    private _colors;
    /**
     * Script
     */
    private _script;
    /**
     * Fonts
     */
    private _font;
    /**
     * Align box
     */
    private _align;
    /**
     * Clean format
     */
    private _clean;
    /**
     * Medias 'link' | 'image' | 'video'
     */
    private _media;
    /**
     * focused
     */
    private _focused;
    /**
     * Dirty
     */
    private _dirty;
    /**
     * Editor value
     */
    value: any;
    /**
     * Editor options
     */
    options: {
        toolbar: {
            container: any[];
        };
    };
    /**
     * MatFormFieldControl variables
     */
    readonly autofilled: boolean;
    readonly controlType: string;
    readonly empty: boolean;
    errorState: boolean;
    focused: boolean;
    readonly id: string;
    readonly ngControl: NgControl | null;
    readonly shouldLabelFloat: boolean;
    stateChanges: Subject<void>;
    /**
     * Inputs
     */
    /**
     *  Configuration input
     */
    config: RhzEditorConfig;
    /**
     * Custom placeholder
     */
    get placeholder(): string;
    set placeholder(plh: string);
    private _placeholder;
    /**
     * Disable element
     */
    get disabled(): boolean;
    set disabled(value: boolean);
    private _disabled;
    /**
     * Set if is required or not
     */
    get required(): boolean;
    set required(req: boolean);
    private _required;
    /**
     * Editor height
     */
    height: number;
    /**
     * Init component
     */
    ngOnInit(): void;
    /**
     * Complete state changes
     */
    ngOnDestroy(): void;
    /**
     * Disable or enable element
     */
    private _disabledElement;
    /**
     * Populate format boxes and configurations
     */
    private _populateConfiguration;
    /**
     * Detect change value
     */
    onChange: any;
    /**
     * Detect on touch
     */
    onTouched: any;
    /**
     * Set value from editor
     * @param value Value passed from editor
     */
    setValue(value: any): void;
    /**
     * Called on touch
     */
    touched(): void;
    /**
     * Called on blur
     */
    blur(): void;
    /**
     * Validate input
     */
    private validation;
    /**
     * Write value
     */
    writeValue(obj: any): void;
    /**
     * Register on change
     */
    registerOnChange(fn: any): void;
    /**
     * Register on touched
     */
    registerOnTouched(fn: any): void;
    /**
     * Set disabled state
     * @param isDisabled
     */
    setDisabledState?(isDisabled: boolean): void;
    /**
     * This method will be called when the form field is clicked on
     * @param event: MouseEvent
     */
    onContainerClick(event: MouseEvent): void;
    /**
     * The setDescribedByIds method is invoked whenever the control's state changes
     * @param ids: string[]
     */
    setDescribedByIds(ids: string[]): void;
}
