import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { RhzFileOutput } from '../../interfaces';
import { RhzConfigService } from '../../services';
export declare class RhzFileSelectorComponent {
    private _cdr;
    private _configService;
    /**
     * Input file element reference
     */
    inputFile: ElementRef;
    /**
     * Sets or retrieves a comma-separated list of content types.
     */
    accept: string;
    /**
     * Max file size (mb)
     * default: 1mb
     * @param value: number
     */
    set maxSize(value: number);
    get maxSize(): number;
    private _maxSize;
    /**
     * Enable multiple file selection
     */
    multiple: boolean;
    /**
     * Selection icon
     */
    icon: string;
    /**
     * Selection text
     */
    label: string;
    /**
     * Emit event with selected valid files
     */
    onSelect: EventEmitter<RhzFileOutput[]>;
    /**
     * Emit event with errors
     */
    onError: EventEmitter<string[]>;
    /**
     * List with last selection errors
     */
    errorList: string[];
    /**
     * Loading control
     */
    loading: boolean;
    private get _hostClasses();
    /**
     * Inject dependencies
     * @param _cdr: ChangeDetectorRef
     * @param _configService: RhzConfigService
     */
    constructor(_cdr: ChangeDetectorRef, _configService: RhzConfigService);
    /**
     * Click on file input and open OS window
     */
    onClickSelect(): void;
    /**
     * Validate and transform files to emit selection event
     * @param ev: any
     */
    onChangeInput(ev: any): Promise<void>;
    /**
     * Emit event with file list
     * @param files: RhzFileOutput[]
     * @private
     */
    private _emitOnSelectOutput;
    /**
     * Emit event with file list
     * @private
     */
    private _emitOnErrorOutput;
    /**
     * Create a file list
     * @param fileList: File[])
     * @private
     */
    private _mapFiles;
    /**
     * Remove illegal characters
     * @param file: File
     * @private
     */
    private _getNormalizedName;
    /**
     * Remove files with invalid sizes from file list
     * @param files: RhzFileOutput[]
     * @private
     */
    private _validateSize;
    /**
     * Remove files with invalid types from file list
     * @param files: RhzFileOutput[]
     * @private
     */
    private _validateTypes;
    /**
     * Convert files from list to base64
     * @param files: RhzFileOutput[]
     * @private
     */
    private _convertToBase64;
    /**
     * Convert File to base64 string
     * @param file: File
     * @private
     */
    private _fileToBase64;
    /**
     * Used to clear/reset input value
     */
    private _clearInputElement;
    /**
     * Validates that the file type is valid
     * by mime or extension
     * @param accept: string
     * @param type: string
     * @param name: string
     * @return boolean
     */
    private _validateAcceptType;
    /**
     * Map errors to string to show in tooltip
     */
    getErrors(): string;
}
