export declare class RhzImageCropConfig {
    private _outputFormat;
    private _aspectRatio;
    private _maintainAspectRatio;
    private _minWidth;
    private _minHeight;
    private _maxWidth;
    private _maxHeight;
    /**
     * Output format (png, jpeg, webp, bmp, ico)
     * (not all browsers support all types, png is always supported, others are optional)
     *
     * default = png
     */
    outputFormat: 'png' | 'jpeg' | 'bmp' | 'webp' | 'ico';
    /**
     * The width / height ratio
     * (e.g. 1 / 1 for a square, 4 / 3, 16 / 9 ...)
     *
     * default = 1;
     */
    aspectRatio: number;
    /**
     * Keep width and height of cropped image
     * equal according to the aspectRatio
     *
     * default = false
     */
    maintainAspectRatio: boolean;
    /**
     * The cropper cannot be made smaller than
     * this number of pixels in width
     * (relative to original image's size) (in px)
     *
     * default = 0 (disabled)
     */
    minWidth: number;
    /**
     * The cropper cannot be made smaller than this
     * number of pixels in height
     * (relative to original image's size) (in px)
     * (will be ignored if maintainAspectRatio is set)
     *
     * default = 0 (disabled)
     */
    minHeight: number;
    /**
     * The cropper cannot be made bigger than
     * this number of pixels in width
     * (relative to original image's size) (in px)
     *
     * default = 0 (disabled)
     */
    maxWidth: number;
    /**
     * The cropper cannot be made bigger than this
     * number of pixels in height
     * (relative to original image's size) (in px)
     * (will be ignored if maintainAspectRatio is set)
     *
     * default = 0 (disabled)
     */
    maxHeight: number;
    constructor(_outputFormat?: 'png' | 'jpeg' | 'bmp' | 'webp' | 'ico', _aspectRatio?: number, _maintainAspectRatio?: boolean, _minWidth?: number, _minHeight?: number, _maxWidth?: number, _maxHeight?: number);
}
