import { ChangeDetectorRef, EventEmitter, OnDestroy } from '@angular/core';
import { ImageCroppedEvent, ImageCropperComponent } from 'ngx-image-cropper';
import { RhzFileOutput } from '../../interfaces';
import { RhzImageCropConfig } from './models/image-crop-config.class';
import { RhzConfigService } from '../../services';
export declare class RhzImageCropComponent implements OnDestroy {
    private cdr;
    private _configService;
    /**
     * Image cropper component reference
     */
    cropper: ImageCropperComponent;
    /**
     * Cropper configs
     */
    config: RhzImageCropConfig;
    /**
     * On close event emitter
     * Emit event with file when confirm
     * and null when cancel
     */
    onClose: EventEmitter<RhzFileOutput>;
    /**
     * Set image to crop
     * @param image: string | File | Blob
     */
    set image(image: string | File | Blob);
    /**
     * Pre defined image filename
     */
    fileName: string;
    /**
     * Base64 image to crop
     */
    imageBase64: string;
    /**
     * File image to crop
     */
    imageFile: File | Blob;
    /**
     * Visibility control
     */
    visible: boolean;
    /**
     * List of errors
     */
    errorList: string[];
    /**
     * Cancel button text
     */
    cancelText: string;
    /**
     * Confirm button text
     */
    confirmText: string;
    /**
     * Config controller
     */
    private _configCtrl;
    /**
     * Inject dependencies
     * @param cdr: ChangeDetectorRef
     * @param _configService: RhzConfigService
     */
    constructor(cdr: ChangeDetectorRef, _configService: RhzConfigService);
    private get _hostClasses();
    ngOnDestroy(): void;
    /**
     * Set default alert config
     * @private
     */
    private _setDefaultConfig;
    /**
     * Show component
     * @param image: string | File | Blob
     * @param fileName: string
     */
    show(image: string | File | Blob, fileName?: string): void;
    /**
     * Hide component and reset crop
     * @param output: RhzFileOutput
     */
    close(output?: RhzFileOutput): void;
    /**
     * Do crop image
     */
    doCrop(): void;
    /**
     * Prepare image when it is cropped
     * and emit event and close
     * @param ev: ImageCroppedEvent
     */
    imageCropped(ev: ImageCroppedEvent): void;
    /**
     * When image loaded, validate dimension
     */
    imageLoaded(): void;
    /**
     * Validate image min and max dimension when enabled
     * @private
     */
    private _validateImageDimension;
    /**
     * Convert base64 image to File/blob
     * @param base64Image: string
     * @param fileName: string
     * @private
     */
    private _base64ToFile;
}
