import { AfterContentInit, ChangeDetectorRef, EventEmitter, OnDestroy, TemplateRef } from '@angular/core';
import { RhzMenuCtrl } from '../classes/menu-ctrl.class';
import { RhzMegaMenuCtrl } from '../classes/mega-menu-ctrl.class';
import { RhzNavbarComponent } from '../rhz-navbar.component';
export declare class RhzNavbarItemComponent implements AfterContentInit, OnDestroy {
    private _navbar;
    private _cdr;
    /**
     * Menu trigger element ref
     * @private
     */
    private _menuTrigger;
    /**
     * Menu content/template ref input
     * @param value: TemplateRef<any>
     */
    set menu(value: TemplateRef<any>);
    get menu(): TemplateRef<any>;
    /**
     * Mega menu content/template ref input
     * @param value: TemplateRef<any>
     */
    set megaMenu(value: TemplateRef<any>);
    get megaMenu(): TemplateRef<any>;
    /**
     * Enable to close menu on leave
     */
    closeMenuOnLeave: boolean;
    /**
     * Menu change status event emitter
     */
    menuChanges: EventEmitter<{
        opened: boolean;
    }>;
    /**
     * Menu controller
     */
    menuCtrl: RhzMenuCtrl;
    /**
     * Mega menu controller
     */
    megaMenuCtrl: RhzMegaMenuCtrl;
    /**
     * Menu template
     * @private
     */
    private _menuTemplate;
    /**
     * Mega menu template
     * @private
     */
    private _megaMenuTemplate;
    /**
     * Menu opened status change subscription
     * @private
     */
    private _menuOpenedSubscription;
    /**
     * Menu closed status change subscription
     * @private
     */
    private _menuClosedSubscription;
    /**
     * Subscribe to mega menu changes
     * @private
     */
    private _megaMenuChangesSubscription;
    /**
     * Inject dependencies
     * @param _navbar: RhzNavbarComponent
     * @param _cdr: ChangeDetectorRef
     */
    constructor(_navbar: RhzNavbarComponent, _cdr: ChangeDetectorRef);
    private get _hostClasses();
    doClick(): void;
    /**
     * Add subscriptions
     */
    ngAfterContentInit(): void;
    /**
     * Remove subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Add menu status changes subscriptions
     */
    private _subscribeMenuChanges;
    /**
     * Add mega menu status changes subscriptions
     */
    private _subscribeMegaMenuChanges;
    /**
     * Check if is medium screen
     */
    isMediumScreen(): boolean;
    /**
     * Close menus
     * @param ev: string
     */
    closeMenus(ev: string): void;
}
