import { ChangeDetectorRef, EventEmitter, OnDestroy } from '@angular/core';
import { RhzScreenSizeService } from '../../services';
export declare class RhzNavbarComponent implements OnDestroy {
    private _screenSize;
    private _cdr;
    /**
     * Brand logo url
     */
    brand: string;
    /**
     * Sidebar menu message
     */
    message: string;
    /**
     * Event fired when click on brand image
     */
    onBrandClick: EventEmitter<any>;
    /**
     * Menu visibility control
     */
    menuOpened: boolean;
    /**
     * Used to verify is screen size medium
     */
    private _isMediumScreen;
    /**
     * Screen sizes subscription
     * @private
     */
    private _screenSizesSubscription;
    /**
     * Inject dependencies
     * @param _screenSize: RhzScreenSizeService
     * @param _cdr: ChangeDetectorRef
     */
    constructor(_screenSize: RhzScreenSizeService, _cdr: ChangeDetectorRef);
    private get _hostClasses();
    /**
     * Close subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Used to show or hide menu
     */
    toggleMenu(): void;
    /**
     * Used to hide menu
     */
    closeMenu(): void;
    /**
     * Used to show menu
     */
    openMenu(): void;
    /**
     * Emit onBrandClick when the logo was clicked
     */
    emitBrandClick(): void;
    /**
     * Observe screen sizes
     * @private
     */
    private observerScreenSize;
    /**
     * Check if is medium screen size
     */
    isMediumScreen(): boolean;
    /**
     * Lock/unblock page scroll
     * @param lock: boolean
     * @private
     */
    private _pageScroll;
}
