import { OnDestroy } from '@angular/core';
import { BreakpointObserver } from '@angular/cdk/layout';
import { Subject } from 'rxjs';
export declare class RhzScreenSizeService implements OnDestroy {
    private _breakpointObserver;
    /**
     * Subject with breakpoints changes
     */
    onBreakpointChange: Subject<{
        [key: string]: boolean;
    }>;
    /**
     * Default RHZ breakpoints
     * Bootstrap based
     * @private
     */
    private _defaultBreakpoints;
    /**
     * Custom breakpoints
     * @private
     */
    private _customBreakpoints;
    /**
     * Breakpoints matches
     * @private
     */
    private _matches;
    /**
     * Breakpoint observer subscription
     */
    private _breakpointObserverSubscription;
    /**
     * Inject dependencies
     * @param _breakpointObserver: BreakpointObserver
     */
    constructor(_breakpointObserver: BreakpointObserver);
    /**
     * Remove subscriptions
     */
    ngOnDestroy(): void;
    /**
     * Add custom breakpoints to observe
     * @param breakpoints: { [key: string]: string }
     */
    setCustomBreakpoints(breakpoints: {
        [key: string]: string;
    }): void;
    /**
     * Get breakpoints matches
     */
    getBreakpoints(): {
        [key: string]: boolean;
    };
    /**
     * Observe screen breakpoints
     * @private
     */
    private _initObserver;
    /**
     * Deal with breakpoint states and set matches
     * @param state: BreakpointState
     * @private
     */
    private _matchBreakpoints;
    /**
     * Close subscriptions
     * @private
     */
    private _unsubscribe;
}
