import { FormGroup, NgForm } from '@angular/forms';
import { ErrorStateMatcher } from '@angular/material/core';
/**
 * Utilities to update/control forms
 */
export declare class FormUtils {
    /**
     * Mark all fields on form as touched
     * @param form: NgForm
     */
    static markFormAsTouched(form: NgForm): void;
    /**
     * Mark all fields on form as untouched
     * @param form: FormGroup
     */
    static markFormAsUnTouched(form: FormGroup): void;
    /**
     * Used to disable all fields
     * @param form: FormGroup
     */
    static disable(form: FormGroup): void;
    /**
     * Used to enable all fields
     * @param form: FormGroup
     */
    static enable(form: FormGroup): void;
    /**
     * Create a input error state matcher
     * @param initialState: boolean
     * @return InputErrorStateMatcher
     */
    static errorStateMatcher(initialState?: boolean): InputErrorStateMatcher;
}
export declare class InputErrorStateMatcher implements ErrorStateMatcher {
    private errorState;
    constructor(errorState?: boolean);
    /**
     * Get error state
     * @return boolean
     */
    isErrorState(): boolean;
    /**
     * Change error state
     * @param value: boolean
     */
    changeState(value: boolean): void;
}
